"use client";
import { createContext, useEffect, useState, ReactNode } from "react";
import { remoteConfig, fetchAndActivate, getValue } from "../lib/firebase";

// Context to store the API key
export const FirebaseConfigContext = createContext<{ apiKey: string | null }>({ apiKey: null });

export const FirebaseRemoteConfigProvider = ({ children }: { children: ReactNode }) => {
  const [apiKey, setApiKey] = useState<string | null>(null);

  useEffect(() => {
    if (!remoteConfig) {
      console.warn("🚨 Remote Config is not available (running on server). Skipping fetch.");
      return; // ✅ Prevents crashes
    }

    const fetchConfig = async () => {
      try {
        // ✅ Type-safe check before calling Firebase functions
        if (!remoteConfig) return;
        await fetchAndActivate(remoteConfig);
        const fetchedApiKey = getValue(remoteConfig, "View").asString();
        setApiKey(fetchedApiKey || null);
      } catch (error) {
        console.error("🔥 Error fetching remote config:", error);
      }
    };

    fetchConfig();
  }, []);

  return (
    <FirebaseConfigContext.Provider value={{ apiKey }}>
      {children}
    </FirebaseConfigContext.Provider>
  );
};
